@@ -189,7 +189,7 @@ class fillVars(varsShare):
             # check root for /dev/sd view
             if re.match("^\/dev\/[a-z]+.*$", rootparam):
                 return getUdevDeviceInfo(
-                   name=rootparam.strip()).get('DEVNAME','')
+                   name=rootparam.strip()).get('DEVNAME',rootparam)
             # check root set by uuid
             if re.match("^UUID=.*$",rootparam):
                 uuid = rootparam[5:].strip("\"'")
@@ -225,7 +225,7 @@ class fillVars(varsShare):
             return (path.normpath(os.path.join(basedir,targetfile)),linkfile)
         rootDev = self.Get("os_root_dev")
         if rootDev:
-            if "/dev/ram" in rootDev:
+            if "/dev/ram" in rootDev or "/dev/nfs" in rootDev:
                 return "livecd"
             idDict = dict(map(link2pair,
                      filter(lambda x:path.islink(x),
@@ -282,7 +282,7 @@ class fillVars(varsShare):
         cpuinfoFile = "/proc/cpuinfo"
         try:
             return len(["" for line in open(cpuinfoFile,"r").readlines()
-                    if "processor" in line])
+                    if line.startswith("processor")])
         except:
             return 1
 
@@ -731,3 +731,9 @@ class fillVars(varsShare):
         if path.exists(timezonefile):
             return open(timezonefile,"r").read().strip()
         return "UTC"
+
+    def get_os_lang(self):
+        """Supported languages"""
+        return list(sorted(list(set(clLocale().getLangs()) &
+            set(["en_US","de_DE","es_ES","fr_FR","it_IT","pl_PL","pt_BR",
+                "uk_UA","bg_BG","ru_RU","ro_RO","pt_PT"]))))
